@@ -6,12 +6,9 @@ import statefulfirewall
 
 
 fw = statefulfirewall.StateFulFireWall()
-l = []
 
 print(fw.protobynumber)
-for i in fw.yield_logs(limit=100):
-        l.append(i)
-for log in l:
+for log in fw.yield_logs(limit=100):
     if 'conntrack_type' in log:
         #print('%-8s %s' % (log['conntrack_type'], log['id']))
         continue
